@@ -1,7 +1,7 @@
 '''
 # @dontirun/state-machine-semaphore
 
-[![npm version](https://img.shields.io/npm/v/donti/state-machine-semaphore.svg)](https://www.npmjs.com/package/@donti%2Fstate-machine-semaphore)
+[![npm version](https://img.shields.io/npm/v/@dontirun/state-machine-semaphore.svg)](https://img.shields.io/npm/v/@dontirun/state-machine-semaphore)
 [![PyPI version](https://img.shields.io/pypi/v/state-machine-semaphore.svg)](https://pypi.org/project/state-machine-semaphore)
 [![NuGet version](https://img.shields.io/nuget/v/Dontirun.StateMachineSemaphore)](https://www.nuget.org/packages/Dontirun.StateMachineSemaphore)
 
@@ -15,13 +15,7 @@ This construct is based off of [Justin Callison's](https://github.com/JustinCall
 
 ### Example 1) A state machine with a controlled job
 
-<table>
-<tr>
-<th>Code</th>
-<th>Definition</th>
-</tr>
-<tr>
-<td>
+<details><summary>Click to see code</summary>
 
 ```python
 import { Function } from 'aws-cdk-lib/aws-lambda';
@@ -29,7 +23,7 @@ import { Duration, Stack, StackProps } from 'aws-cdk-lib';
 import { StateMachine, Succeed, Wait, WaitTime } from 'aws-cdk-lib/aws-stepfunctions';
 import { LambdaInvoke } from 'aws-cdk-lib/aws-stepfunctions-tasks';
 import { Construct } from 'constructs';
-import { SemaphoreGenerator } from '@dontirun/state-machine-semaphore';
+import { Semaphore } from '@dontirun/state-machine-semaphore';
 
 
 export class CdkTestStack extends Stack {
@@ -44,8 +38,7 @@ export class CdkTestStack extends Stack {
 
     const afterContestedJob = new Succeed(this, 'Succeed');
 
-    const generator = new SemaphoreGenerator(this, 'SemaphoreGenerator');
-    const stateMachineFragment = generator.generateSemaphoredJob('life', 42, contestedJob, afterContestedJob);
+    const stateMachineFragment = new Semaphore(stack, 'Semaphore', { lockName: 'life', limit: 42, job: contestedJob, nextState: afterContestedJob });
 
     new StateMachine(this, 'StateMachine', {
       definition: stateMachineFragment,
@@ -54,24 +47,15 @@ export class CdkTestStack extends Stack {
 }
 ```
 
-</td>
-<td>
+</details><details><summary>Click to see the state machine definition</summary>
 
 ![Example 1 Definition](./images/Example1_Graph_Edit.png)
 
-</td>
-</tr>
-</table>
+</details>
 
 ### Example 2) A state machine with multiple semaphores
 
-<table>
-<tr>
-<th>Code</th>
-<th>Definition</th>
-</tr>
-<tr>
-<td>
+<details><summary>Click to see code</summary>
 
 ```python
 import { Function } from 'aws-cdk-lib/aws-lambda';
@@ -79,7 +63,7 @@ import { Duration, Stack, StackProps } from 'aws-cdk-lib';
 import { StateMachine, Succeed, Wait, WaitTime } from 'aws-cdk-lib/aws-stepfunctions';
 import { LambdaInvoke } from 'aws-cdk-lib/aws-stepfunctions-tasks';
 import { Construct } from 'constructs';
-import { SemaphoreGenerator } from '@dontirun/state-machine-semaphore';
+import { Semaphore } from '@dontirun/state-machine-semaphore';
 
 
 export class CdkTestStack extends Stack {
@@ -97,25 +81,21 @@ export class CdkTestStack extends Stack {
     })
     const afterContestedJob2 = new Succeed(this, 'Succeed');
 
-    const generator = new SemaphoreGenerator(this, 'SemaphoreGenerator');
-    const stateMachineFragment = generator.generateSemaphoredJob('life', 42, contestedJob, notContestedJob);
-    const stateMachineFragment2 = generator.generateSemaphoredJob('liberty', 7, contestedJob2, afterContestedJob2);
+    const definition = new Semaphore(stack, 'Semaphore', { lockName: 'life', limit: 42, job: contestedJob, nextState: notContestedJob })
+      .next(new Semaphore(stack, 'Semaphore2', { lockName: 'liberty', limit: 7, job: contestedJob2, nextState: afterContestedJob2 }));
 
     new StateMachine(this, 'StateMachine', {
-      definition: stateMachineFragment.next(stateMachineFragment2),
+      definition: definition,
     });
   }
 }
 ```
 
-</td>
-<td>
+</details><details><summary>Click to see the state machine definition</summary>
 
 ![Example 2 Definition](./images/Example2_Graph_Edit.png)
 
-</td>
-</tr>
-</table>
+</details>
 
 ## API Reference
 
@@ -163,98 +143,177 @@ class _IChainNextableProxy(
 typing.cast(typing.Any, IChainNextable).__jsii_proxy_class__ = lambda : _IChainNextableProxy
 
 
-class SemaphoreGenerator(
-    constructs.Construct,
+class Semaphore(
+    aws_cdk.aws_stepfunctions.StateMachineFragment,
     metaclass=jsii.JSIIMeta,
-    jsii_type="@dontirun/state-machine-semaphore.SemaphoreGenerator",
+    jsii_type="@dontirun/state-machine-semaphore.Semaphore",
 ):
-    '''Sets up up the DynamoDB table that stores the State Machine semaphores.
-
-    Call ``generateSemaphoredJob`` to generate semaphored jobs.
-    '''
+    '''Generates a semaphore for a StepFunction job (or chained set of jobs) to limit parallelism across executions.'''
 
     def __init__(
         self,
         scope: constructs.Construct,
         id: builtins.str,
         *,
+        job: IChainNextable,
+        limit: jsii.Number,
+        lock_name: builtins.str,
+        next_state: aws_cdk.aws_stepfunctions.State,
+        comments: typing.Optional[builtins.bool] = None,
+        reuse_lock: typing.Optional[builtins.bool] = None,
         table_read_write_capacity: typing.Optional[typing.Union["TableReadWriteCapacity", typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param table_read_write_capacity: Optionally set the DynamoDB table to have a specific read/write capacity with PROVISIONED billing. Default: PAY_PER_REQUEST
+        :param job: The job (or chained jobs) to be semaphored.
+        :param limit: The maximum number of concurrent executions for the given lock.
+        :param lock_name: The name of the semaphore.
+        :param next_state: The State to go to after the semaphored job completes.
+        :param comments: Add detailed comments to lock related states. Significantly increases CloudFormation template size. Default: false.
+        :param reuse_lock: Explicility allow the reuse of a named lock from a previously generated job. Throws an error if a different ``limit`` is specified. Default: false.
+        :param table_read_write_capacity: Optionally set the DynamoDB table to have a specific read/write capacity with PROVISIONED billing. Note: This property can only be set on the first instantiation of a ``Semaphore`` per stack Default: PAY_PER_REQUEST
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SemaphoreGenerator.__init__)
+            type_hints = typing.get_type_hints(Semaphore.__init__)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        props = SemaphoreGeneratorProps(
-            table_read_write_capacity=table_read_write_capacity
+        props = SemaphoreProps(
+            job=job,
+            limit=limit,
+            lock_name=lock_name,
+            next_state=next_state,
+            comments=comments,
+            reuse_lock=reuse_lock,
+            table_read_write_capacity=table_read_write_capacity,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @jsii.member(jsii_name="generateSemaphoredJob")
-    def generate_semaphored_job(
-        self,
-        lock_name: builtins.str,
-        limit: jsii.Number,
-        job: IChainNextable,
-        next_state: aws_cdk.aws_stepfunctions.State,
-        reuse_lock: typing.Optional[builtins.bool] = None,
-        comments: typing.Optional[builtins.bool] = None,
-    ) -> aws_cdk.aws_stepfunctions.StateMachineFragment:
-        '''Generates a semaphore for a StepFunction job (or chained set of jobs) to limit parallelism across executions.
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="endStates")
+    def end_states(self) -> typing.List[aws_cdk.aws_stepfunctions.INextable]:
+        '''The states to chain onto if this fragment is used.'''
+        return typing.cast(typing.List[aws_cdk.aws_stepfunctions.INextable], jsii.get(self, "endStates"))
 
-        :param lock_name: The name of the semaphore.
-        :param limit: The maximum number of concurrent executions for the given lock.
-        :param job: The job (or chained jobs) to be semaphored.
-        :param next_state: The State to go to after the semaphored job completes.
-        :param reuse_lock: Explicility allow the reuse of a named lock from a previously generated job. Throws an error if a different ``limit`` is specified. Default: false.
-        :param comments: Adds detailed comments to lock related states. Significantly increases CloudFormation template size. Default: false.
-
-        :return: A StateMachineFragment that can chained to other states in the State Machine.
-        '''
-        if __debug__:
-            type_hints = typing.get_type_hints(SemaphoreGenerator.generate_semaphored_job)
-            check_type(argname="argument lock_name", value=lock_name, expected_type=type_hints["lock_name"])
-            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
-            check_type(argname="argument job", value=job, expected_type=type_hints["job"])
-            check_type(argname="argument next_state", value=next_state, expected_type=type_hints["next_state"])
-            check_type(argname="argument reuse_lock", value=reuse_lock, expected_type=type_hints["reuse_lock"])
-            check_type(argname="argument comments", value=comments, expected_type=type_hints["comments"])
-        return typing.cast(aws_cdk.aws_stepfunctions.StateMachineFragment, jsii.invoke(self, "generateSemaphoredJob", [lock_name, limit, job, next_state, reuse_lock, comments]))
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="startState")
+    def start_state(self) -> aws_cdk.aws_stepfunctions.State:
+        '''The start state of this state machine fragment.'''
+        return typing.cast(aws_cdk.aws_stepfunctions.State, jsii.get(self, "startState"))
 
 
 @jsii.data_type(
-    jsii_type="@dontirun/state-machine-semaphore.SemaphoreGeneratorProps",
+    jsii_type="@dontirun/state-machine-semaphore.SemaphoreProps",
     jsii_struct_bases=[],
-    name_mapping={"table_read_write_capacity": "tableReadWriteCapacity"},
+    name_mapping={
+        "job": "job",
+        "limit": "limit",
+        "lock_name": "lockName",
+        "next_state": "nextState",
+        "comments": "comments",
+        "reuse_lock": "reuseLock",
+        "table_read_write_capacity": "tableReadWriteCapacity",
+    },
 )
-class SemaphoreGeneratorProps:
+class SemaphoreProps:
     def __init__(
         self,
         *,
+        job: IChainNextable,
+        limit: jsii.Number,
+        lock_name: builtins.str,
+        next_state: aws_cdk.aws_stepfunctions.State,
+        comments: typing.Optional[builtins.bool] = None,
+        reuse_lock: typing.Optional[builtins.bool] = None,
         table_read_write_capacity: typing.Optional[typing.Union["TableReadWriteCapacity", typing.Dict[str, typing.Any]]] = None,
     ) -> None:
-        '''Interface for creating a SemaphoreGenerator.
+        '''Interface for creating a Semaphore.
 
-        :param table_read_write_capacity: Optionally set the DynamoDB table to have a specific read/write capacity with PROVISIONED billing. Default: PAY_PER_REQUEST
+        :param job: The job (or chained jobs) to be semaphored.
+        :param limit: The maximum number of concurrent executions for the given lock.
+        :param lock_name: The name of the semaphore.
+        :param next_state: The State to go to after the semaphored job completes.
+        :param comments: Add detailed comments to lock related states. Significantly increases CloudFormation template size. Default: false.
+        :param reuse_lock: Explicility allow the reuse of a named lock from a previously generated job. Throws an error if a different ``limit`` is specified. Default: false.
+        :param table_read_write_capacity: Optionally set the DynamoDB table to have a specific read/write capacity with PROVISIONED billing. Note: This property can only be set on the first instantiation of a ``Semaphore`` per stack Default: PAY_PER_REQUEST
         '''
         if isinstance(table_read_write_capacity, dict):
             table_read_write_capacity = TableReadWriteCapacity(**table_read_write_capacity)
         if __debug__:
-            type_hints = typing.get_type_hints(SemaphoreGeneratorProps.__init__)
+            type_hints = typing.get_type_hints(SemaphoreProps.__init__)
+            check_type(argname="argument job", value=job, expected_type=type_hints["job"])
+            check_type(argname="argument limit", value=limit, expected_type=type_hints["limit"])
+            check_type(argname="argument lock_name", value=lock_name, expected_type=type_hints["lock_name"])
+            check_type(argname="argument next_state", value=next_state, expected_type=type_hints["next_state"])
+            check_type(argname="argument comments", value=comments, expected_type=type_hints["comments"])
+            check_type(argname="argument reuse_lock", value=reuse_lock, expected_type=type_hints["reuse_lock"])
             check_type(argname="argument table_read_write_capacity", value=table_read_write_capacity, expected_type=type_hints["table_read_write_capacity"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[str, typing.Any] = {
+            "job": job,
+            "limit": limit,
+            "lock_name": lock_name,
+            "next_state": next_state,
+        }
+        if comments is not None:
+            self._values["comments"] = comments
+        if reuse_lock is not None:
+            self._values["reuse_lock"] = reuse_lock
         if table_read_write_capacity is not None:
             self._values["table_read_write_capacity"] = table_read_write_capacity
 
+    @builtins.property
+    def job(self) -> IChainNextable:
+        '''The job (or chained jobs) to be semaphored.'''
+        result = self._values.get("job")
+        assert result is not None, "Required property 'job' is missing"
+        return typing.cast(IChainNextable, result)
+
+    @builtins.property
+    def limit(self) -> jsii.Number:
+        '''The maximum number of concurrent executions for the given lock.'''
+        result = self._values.get("limit")
+        assert result is not None, "Required property 'limit' is missing"
+        return typing.cast(jsii.Number, result)
+
+    @builtins.property
+    def lock_name(self) -> builtins.str:
+        '''The name of the semaphore.'''
+        result = self._values.get("lock_name")
+        assert result is not None, "Required property 'lock_name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def next_state(self) -> aws_cdk.aws_stepfunctions.State:
+        '''The State to go to after the semaphored job completes.'''
+        result = self._values.get("next_state")
+        assert result is not None, "Required property 'next_state' is missing"
+        return typing.cast(aws_cdk.aws_stepfunctions.State, result)
+
+    @builtins.property
+    def comments(self) -> typing.Optional[builtins.bool]:
+        '''Add detailed comments to lock related states.
+
+        Significantly increases CloudFormation template size. Default: false.
+        '''
+        result = self._values.get("comments")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def reuse_lock(self) -> typing.Optional[builtins.bool]:
+        '''Explicility allow the reuse of a named lock from a previously generated job.
+
+        Throws an error if a different ``limit`` is specified. Default: false.
+        '''
+        result = self._values.get("reuse_lock")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def table_read_write_capacity(self) -> typing.Optional["TableReadWriteCapacity"]:
         '''Optionally set the DynamoDB table to have a specific read/write capacity with PROVISIONED billing.
 
+        Note: This property can only be set on the first instantiation of a ``Semaphore`` per stack
+
         :default: PAY_PER_REQUEST
         '''
         result = self._values.get("table_read_write_capacity")
@@ -267,7 +326,7 @@ class SemaphoreGeneratorProps:
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return "SemaphoreGeneratorProps(%s)" % ", ".join(
+        return "SemaphoreProps(%s)" % ", ".join(
             k + "=" + repr(v) for k, v in self._values.items()
         )
 
@@ -324,8 +383,8 @@ class TableReadWriteCapacity:
 
 __all__ = [
     "IChainNextable",
-    "SemaphoreGenerator",
-    "SemaphoreGeneratorProps",
+    "Semaphore",
+    "SemaphoreProps",
     "TableReadWriteCapacity",
 ]
 
